@@ -1,5 +1,5 @@
-use std::{sync::Arc, time::Duration};
-
+use core::time::Duration;
+use ockam_core::compat::{sync::Arc, vec::Vec};
 use ockam_core::{
     Address, AddressSet, LocalMessage, Message, Result, Route, TransportMessage, Worker,
 };
