@@ -1,8 +1,8 @@
 use crate::{
     error::Error, relay::RelayMessage, AddressRecord, NodeMessage, NodeReply, NodeReplyResult,
 };
+use ockam_core::compat::collections::BTreeMap;
 use ockam_core::{Address, AddressSet, Result};
-use std::collections::BTreeMap;
 use tokio::sync::mpsc::{channel, Receiver, Sender};
 
 /// A combined address type and local worker router
@@ -131,6 +131,13 @@ impl Router {
 
         self.internal.insert(primary_addr.clone(), address_record);
 
+        #[cfg(feature = "std")]
+        if std::env::var("OCKAM_DUMP_INTERNALS").is_ok() {
+            trace!("{:#?}", self.internal);
+        }
+        #[cfg(all(not(feature = "std"), feature = "dump_internals"))]
+        trace!("{:#?}", self.internal);
+
         addrs.iter().for_each(|addr| {
             self.addr_map.insert(addr.clone(), primary_addr.clone());
         });
